@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 __title__ = "text2svg"
-__version__ = "0.0.1"
-__summary__ = "convert text to svg"
+__version__ = "0.2.0"
+__summary__ = "Convert text to svg"
 __uri__ = "https://github.com/naveen521kk/text2svg"
 __author__ = "Naveen M K"
-__license__ = "GPLv3"
\ No newline at end of file
+__license__ = "GPLv3"
